/*
 *  particle.cpp
 *  emptyExample
 *
 *  Created by Kate Watkins on 10/16/11.
 *  Copyright 2011 Parsons New School of Design. All rights reserved.
 *
 */

#include "particle.h"
#include "ofMain.h"


//------------------------------------------------------------
particle::particle(){
	setInitialCondition(0,0,0,0);
	damping = 0.09f;
}

//------------------------------------------------------------
void particle::resetForce(){
    // we reset the forces every frame
    frc.set(0,0);
}

//------------------------------------------------------------
void particle::addForce(float x, float y){
    // add in a force in X and Y for this frame.
    frc.x = frc.x + x;
    frc.y = frc.y + y;
}

//------------------------------------------------------------
void particle::addDampingForce(){
	
	// the usual way to write this is  vel *= 0.99
	// basically, subtract some part of the velocity 
	// damping is a force operating in the oposite direction of the 
	// velocity vector
	
    frc.x = frc.x - vel.x * damping;
    frc.y = frc.y - vel.y * damping;
}

//------------------------------------------------------------
void particle::setInitialCondition(float px, float py, float vx, float vy){
    pos.set(px,py);
	vel.set(vx,vy);
}

//------------------------------------------------------------
void particle::update(){	
	vel = vel + frc;
	pos = pos + vel;
}

//------------------------------------------------------------
void particle::draw(){
    
	//ofCircle(pos.x, pos.y, 3);
	
	//
//	float modulator = ofMap( sin(ofGetElapsedTimef()/PI), -1, 1, -1, -1);
//	float radius =  i * modulator2;
//	float angle = ofGetElapsedTimef() * modulator4 - i;
//	float x = xorig + angle / (-cos(angle)/modulator2);
//	float y = yorig + radius * (sin(angle)*modulator3);
	
	
	ofEnableAlphaBlending();
	
	
	float modulator = ofMap( sin(ofGetElapsedTimef()/PI), -1, 1, -1, -1);
	float radius = modulator;
	float angle = ofGetElapsedTimef() * modulator;
	float x =  radius  - cos(angle)*modulator;
	float y =  radius * sin(angle)*modulator;
	float r =  197; 
	float g =  119; 
	float b =  200; 
	float alpha = ofRandom(97,100); 
	
	ofPushMatrix();
	
		ofTranslate(pos.x, pos.y, 0);
		ofRotateZ(angle * RAD_TO_DEG);
		ofCircle(x,y, 10);
		//ofSetColor(198,246,55); 
		ofSetColor(r,g,b); 
		ofCircle(x+4, y+8, 5.5); 
	
	ofPopMatrix();
	
	ofPushMatrix();
		ofTranslate(pos.x, pos.y, 0);
		ofRotateZ(angle * RAD_TO_DEG);
		ofSetColor(255,20,200); 
		//ofSetColor(r-10,g+46,b+40,alpha); 
		ofCircle(x-2, y-5, 3); 
	ofPopMatrix(); 
	
	ofPushMatrix(); 
		ofTranslate(pos.x, pos.y, 0);
		ofRotateZ(angle * RAD_TO_DEG);
		ofSetColor(r-90,g+40,b+70,alpha);
		ofCircle(x+2, y+5, 5);
	ofPopMatrix(); 
	
	
	//ofSetColor(198,246,55);
	
	
	ofDisableAlphaBlending(); 
}


//------------------------------------------------------------
void particle::bounceOffWalls(){
	
	// sometimes it makes sense to damped, when we hit
	bool bDampedOnCollision = true;
	bool bDidICollide = false
	;
	
	// what are the walls
	float minx = 0;
	float miny = 0;
	float maxx = ofGetWidth();
	float maxy = ofGetHeight();
	
	if (pos.x > maxx){
		pos.x = maxx; // move to the edge, (important!)
		vel.x *= -1;
		bDidICollide = true;
	} else if (pos.x < minx){
		pos.x = minx; // move to the edge, (important!)
		vel.x *= -1;
		bDidICollide = true;
	}
	
	if (pos.y > maxy){
		pos.y = maxy; // move to the edge, (important!)
		vel.y *= -1;
		bDidICollide = true;
	} else if (pos.y < miny){
		pos.y = miny; // move to the edge, (important!)
		vel.y *= -1;
		bDidICollide = true;
	}
	
	if (bDidICollide == true && bDampedOnCollision == true){
	//	vel *= 0.3;
		vel *= 0.9;
	}
	
}

//------------------------------------------------------------------
void particle::xenoToPoint(float catchX, float catchY){
	
	
	pos.x = catchUpSpeed * catchX + (1-catchUpSpeed) * pos.x; 
	pos.y = catchUpSpeed * catchY + (1-catchUpSpeed) * pos.y; 
	
	float dx = pos.x - prevPos.x;
	float dy = pos.y - prevPos.y;
	
	angle = atan2(dy, dx);
	
	prevPos.x = pos.x;
	prevPos.y = pos.y;
	
	
}
